summaryrefslogtreecommitdiffstats
path: root/content/browser/zygote_host_linux.h
diff options
context:
space:
mode:
Diffstat (limited to 'content/browser/zygote_host_linux.h')
-rw-r--r--content/browser/zygote_host_linux.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/content/browser/zygote_host_linux.h b/content/browser/zygote_host_linux.h
index 5ead5f5..9098e6d 100644
--- a/content/browser/zygote_host_linux.h
+++ b/content/browser/zygote_host_linux.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2009 The Chromium Authors. All rights reserved.
+// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -32,10 +32,12 @@ class ZygoteHost {
void Init(const std::string& sandbox_cmd);
// Tries to start a renderer process. Returns its pid on success, otherwise
// base::kNullProcessHandle;
- pid_t ForkRenderer(const std::vector<std::string>& command_line,
- const base::GlobalDescriptors::Mapping& mapping);
+ pid_t ForkRequest(const std::vector<std::string>& command_line,
+ const base::GlobalDescriptors::Mapping& mapping,
+ const std::string& process_type);
void EnsureProcessTerminated(pid_t process);
// Get the termination status (and, optionally, the exit code) of
@@ -32,10 +32,12 @@ class ZygoteHost {
void Init(const std::string& sandbox_cmd);
- // Tries to start a renderer process. Returns its pid on success, otherwise
+ // Tries to start a process of type indicated by process_type.
+ // Returns its pid on success, otherwise
// base::kNullProcessHandle;